@@ -1,7 +1,6 @@
-
 with_subscript_errors <- function(expr, type = "select") {
   tryCatch(
-    instrument_base_errors(expr),
+    with_entraced_errors(expr),
 
     vctrs_error_subscript = function(cnd) {
       cnd$subscript_action <- subscript_action(type)
@@ -10,12 +9,16 @@ with_subscript_errors <- function(expr, type = "select") {
     }
   )
 }
-instrument_base_errors <- function(expr) {
-  withCallingHandlers(
+
+with_entraced_errors <- function(expr) {
+  try_fetch(
     expr,
     simpleError = function(cnd) {
-      # Pass `cnd` as parent to ensure proper backtraces
-      abort(conditionMessage(cnd), parent = cnd)
+      # TODO! `parent = NA`
+      abort(
+        conditionMessage(cnd),
+        call = conditionCall(cnd)
+      )
     }
   )
 }
