@@ -1,4 +1,3 @@
-
 test_that("leaves of data expression tree are evaluated in the context", {
   wrapper <- function(x, var) select_loc(x, {{ var }}:length(x))
   expect_identical(wrapper(letters2, x), select_loc(letters2, x:26))
@@ -90,7 +89,7 @@ test_that("boolean operators are overloaded", {
 })
 
 test_that("scalar boolean operators fail informatively", {
-  verify_output(test_path("outputs", "vars-select-bool-scalar-ops.txt"), {
+  expect_snapshot(error = TRUE, {
     select_loc(letters2, starts_with("a") || ends_with("b"))
     select_loc(letters2, starts_with("a") && ends_with("b"))
   })
@@ -113,7 +112,7 @@ test_that("can't use `*` and `^` in data context", {
   expect_error(select_loc(letters2, a * 2), "arithmetic")
   expect_error(select_loc(letters2, a^2), "arithmetic")
 
-  verify_output(test_path("outputs", "vars-select-num-ops.txt"), {
+  expect_snapshot(error = TRUE, {
     select_loc(letters2, a * 2)
     select_loc(letters2, a^2)
   })
@@ -131,13 +130,13 @@ test_that("symbol lookup outside data informs caller about better practice", {
   expect_message(select_loc(letters2, vars1))
 
   vars2 <- c("a", "b") # To force a message the second time
-  verify_output(test_path("outputs", "vars-select-context-lookup.txt"), {
+  expect_snapshot(error = TRUE, {
     select_loc(letters2, vars2)
   })
 })
 
 test_that("symbol evaluation only informs once (#184)", {
-  verify_output(test_path("outputs", "eval-sym-verbosity.txt"), {
+  expect_snapshot({
     "Default"
     with_options(tidyselect_verbosity = NULL, {
       `_vars_default` <- "cyl"
@@ -178,7 +177,7 @@ test_that("symbol evaluation informs from global environment but not packages",
 })
 
 test_that("selection helpers are in the context mask", {
-  out <- local(envir = baseenv(), {
+  out <- local(envir = env(base_env()), {
     letters2 <- rlang::set_names(letters)
     tidyselect::eval_select(quote(all_of("a")), letters2)
   })
@@ -263,7 +262,7 @@ test_that("unique elements are returned", {
 })
 
 test_that("selections provide informative errors", {
-  verify_output(test_path("outputs", "eval-errors.txt"), {
+  expect_snapshot(error = TRUE, {
     "Foreign errors during evaluation"
     select_loc(iris, eval_tidy(foobar))
   })
@@ -327,17 +326,8 @@ test_that("eval_sym() still supports predicate functions starting with `is`", {
   expect_identical(select_loc(iris, isTRUE), select_loc(iris, where(isTRUE)))
 })
 
-test_that("formula shorthand must be wrapped", {
-  verify_errors({
-    expect_error(select_loc(mtcars, ~ is.numeric(.x)))
-    expect_error(select_loc(mtcars, ~ is.numeric(.x) || is.factor(.x) || is.character(.x)))
-    expect_error(select_loc(mtcars, ~ is.numeric(.x) || is.factor(.x) || is.character(.x) ||
-                                      is.numeric(.x) || is.factor(.x) || is.character(.x)))
-  })
-})
-
 test_that("eval_walk() has informative messages", {
-  verify_output(test_path("outputs", "test-helpers-where.txt"), {
+  expect_snapshot({
     "# Using a predicate without where() warns"
     invisible(select_loc(iris, is_integer))
     invisible(select_loc(iris, is.numeric))
@@ -347,9 +337,11 @@ test_that("eval_walk() has informative messages", {
     invisible(select_loc(iris, is_integer))
 
     "formula shorthand must be wrapped"
-    select_loc(mtcars, ~ is.numeric(.x))
-    select_loc(mtcars, ~ is.numeric(.x) || is.factor(.x) || is.character(.x))
-    select_loc(mtcars, ~ is.numeric(.x) || is.factor(.x) || is.character(.x) ||
-                         is.numeric(.x) || is.factor(.x) || is.character(.x))
+    (expect_error(select_loc(mtcars, ~ is.numeric(.x))))
+    (expect_error(select_loc(mtcars, ~ is.numeric(.x) || is.factor(.x) || is.character(.x))))
+    (expect_error(select_loc(mtcars, ~ is.numeric(.x) || is.factor(.x) || is.character(.x) ||
+                                       is.numeric(.x) || is.factor(.x) || is.character(.x))))
+
+    (expect_error(select_loc(mtcars, .data$"foo")))
   })
 })
